drdynvc

package
v0.6.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 23, 2026 License: GPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	DYNVC_CREATE_REQ            = 0x01
	DYNVC_DATA_FIRST            = 0x02
	DYNVC_DATA                  = 0x03
	DYNVC_CLOSE                 = 0x04
	DYNVC_CAPABILITIES          = 0x05
	DYNVC_DATA_FIRST_COMPRESSED = 0x06
	DYNVC_DATA_COMPRESSED       = 0x07
	DYNVC_SOFT_SYNC_REQUEST     = 0x08
	DYNVC_SOFT_SYNC_RESPONSE    = 0x09
)
const (
	MAX_DVC_CHANNELS = 20
)

Variables

This section is empty.

Functions

This section is empty.

Types

type ChannelClient

type ChannelClient struct {
	// contains filtered or unexported fields
}

type DvcChannelHandler added in v0.4.5

type DvcChannelHandler interface {
	Process(data []byte)
}

DvcChannelHandler processes data for a specific dynamic virtual channel.

type DvcClient

type DvcClient struct {
	// contains filtered or unexported fields
}

func NewDvcClient

func NewDvcClient() *DvcClient

func (*DvcClient) GetType

func (c *DvcClient) GetType() (string, uint32)

func (*DvcClient) LoadAddin

func (c *DvcClient) LoadAddin(f core.ChannelSender)

func (*DvcClient) Process

func (c *DvcClient) Process(s []byte)

func (*DvcClient) RegisterHandler added in v0.4.5

func (c *DvcClient) RegisterHandler(name string, handler DvcChannelHandler)

RegisterHandler registers a handler for a named DVC channel.

func (*DvcClient) RegisterRejectedChannel added in v0.5.0

func (c *DvcClient) RegisterRejectedChannel(name string)

RegisterRejectedChannel marks a DVC channel to be explicitly rejected (non-zero CreationStatus) so the server does not use it. Use this to steer servers toward a fallback channel; for example, rejecting AUDIO_PLAYBACK_LOSSY_DVC forces gnome-remote-desktop to fall back to lossless AUDIO_PLAYBACK_DVC (PCM).

func (*DvcClient) Send

func (c *DvcClient) Send(s []byte) (int, error)

func (*DvcClient) SendDvcData added in v0.4.5

func (c *DvcClient) SendDvcData(channelId uint32, data []byte)

SendDvcData sends data on a DVC channel wrapped in a DYNVC_DATA PDU.

func (*DvcClient) Sender

func (c *DvcClient) Sender(f core.ChannelSender)

type DvcHeader

type DvcHeader struct {
	// contains filtered or unexported fields
}

Jump to